OidcProvider

Enum OidcProvider 

pub enum OidcProvider {
    Google,
    Apple,
    Microsoft,
    Custom {
        issuer: String,
        jwks_url: String,
    },
}
Available on crate feature keyless only.
Supported OIDC providers.

Variants



Google

Google identity provider.



Apple

Apple identity provider.



Microsoft

Microsoft identity provider.



Custom

Custom OIDC provider.

Fields

issuer: String

Issuer URL.

jwks_url: String

JWKS URL.

Implementations

Source

impl OidcProvider

pub fn issuer(&self) -> &str

Returns the issuer URL.

pub fn jwks_url(&self) -> &str

Returns the JWKS URL.

pub fn from_issuer(issuer: &str) -> Self

Infers a provider from an issuer URL.

Security

For unknown issuers, the JWKS URL is constructed as {issuer}/.well-known/jwks.json. Non-HTTPS issuers are accepted at construction time but will produce an empty JWKS URL, causing a clear error at JWKS fetch time. This prevents SSRF via http://, file://, or other dangerous URL schemes without changing the function signature. Callers controlling issuer input should additionally validate the host (e.g., block private IP ranges) if SSRF is a concern.