pub struct Secp256k1Account { /* private fields */ }Available on crate feature
secp256k1 only.Expand description
A Secp256k1 ECDSA account for signing transactions.
This account type uses the same elliptic curve as Bitcoin and Ethereum.
Example
use aptos_sdk::account::Secp256k1Account;
let account = Secp256k1Account::generate();
println!("Address: {}", account.address());Implementations
Sourceimpl Secp256k1Account
impl Secp256k1Account
Sourcepub fn from_private_key(private_key: Secp256k1PrivateKey) -> Self
pub fn from_private_key(private_key: Secp256k1PrivateKey) -> Self
Creates an account from a private key.
Sourcepub fn from_private_key_bytes(bytes: &[u8]) -> AptosResult<Self>
pub fn from_private_key_bytes(bytes: &[u8]) -> AptosResult<Self>
Creates an account from private key bytes.
Errors
Returns an error if the bytes are not a valid Secp256k1 private key (must be exactly 32 bytes and a valid curve point).
Sourcepub fn from_private_key_hex(hex_str: &str) -> AptosResult<Self>
pub fn from_private_key_hex(hex_str: &str) -> AptosResult<Self>
Creates an account from a private key hex string.
Errors
This function will return an error if:
- The hex string is invalid or cannot be decoded
- The decoded bytes are not a valid Secp256k1 private key
Sourcepub fn address(&self) -> AccountAddress
pub fn address(&self) -> AccountAddress
Returns the account address.
Sourcepub fn public_key(&self) -> &Secp256k1PublicKey
pub fn public_key(&self) -> &Secp256k1PublicKey
Returns the public key.
Sourcepub fn private_key(&self) -> &Secp256k1PrivateKey
pub fn private_key(&self) -> &Secp256k1PrivateKey
Returns a reference to the private key.
Sourcepub fn sign_message(&self, message: &[u8]) -> Secp256k1Signature
pub fn sign_message(&self, message: &[u8]) -> Secp256k1Signature
Signs a message and returns the Secp256k1 signature.