pub struct Pepper(/* private fields */);Available on crate feature
keyless only.Expand description
Pepper bytes used in keyless address derivation.
Security
The pepper is secret material used to derive keyless account addresses. It is automatically zeroized when dropped to prevent key material from lingering in memory.
Implementations